API Docs — MCT Documentation: ver 1.0.0

# API Docs

Init module for MCT API.

    import model_compression_toolkit as mct

## Methods

- keras_post_training_quantization: Method to use for post training quantization of Keras models.

## Modules

- quantization_config: Module to configure the quantization process.

- network_editor: Module to edit your model during the quantization process.

## Classes

- KnowledgeDistillationConfig: Class to configure KnowledgeDistillation options for post training quantization.

- FolderImageLoader: Class to use an images directory as a representative dataset.

- FrameworkInfo: Class to wrap framework information to be used by MCT when optimizing models.

## Indices and tables

- Index

- Module Index

- Search Page

Note

This documentation is auto-generated using Sphinx